@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -29,15 +29,15 @@ be a "in (str, unicode)" rather than making useless version checks.
 # pylint: disable=C0103,W0622
 
 # Work around for CPython 3.x renaming "long" to "int".
-try:
+if str is bytes:
     long = long  # @ReservedAssignment
-except NameError:
+else:
     long = int   # @ReservedAssignment
 
 # Work around for CPython 3.x renaming "unicode" to "str".
-try:
+if str is bytes:
     unicode = unicode  # @ReservedAssignment
-except NameError:
+else:
     unicode = str      # @ReservedAssignment
 
 def iterItems(d):
@@ -46,17 +46,31 @@ def iterItems(d):
     except AttributeError:
         return d.items()
 
-if unicode is str:
+if str is not bytes:
     raw_input = input      # @ReservedAssignment
 else:
     raw_input = raw_input  # @ReservedAssignment
 
+if str is bytes:
+    xrange = xrange # @ReservedAssignment
+else:
+    xrange = range  # @ReservedAssignment
+
+
 try:
     from urllib.request import urlretrieve
 except ImportError:
     from urllib import urlretrieve
 
+
+try:
+    from cStringIO import StringIO
+except ImportError:
+    from io import StringIO
+
 # For PyLint to be happy.
 assert long
 assert unicode
 assert urlretrieve
+assert StringIO
+assert type(xrange) is type, xrange
