@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -41,7 +41,8 @@ from logging import warning
 
 from nuitka import Options
 from nuitka.containers import oset
-from nuitka.plugins.PluginBase import Plugins
+from nuitka.plugins.Plugins import Plugins
+from nuitka.PythonVersions import python_version
 from nuitka.utils import Utils
 
 from .PreloadedPackages import getPreloadedPackagePath, isPreloadedPackagePath
@@ -75,7 +76,7 @@ def isPackageDir(dirname):
 
     return Utils.isDir(dirname) and \
            (
-               Utils.python_version >= 330 or
+               python_version >= 330 or
                Utils.isFile(Utils.joinpath(dirname, "__init__.py")) or
                isPreloadedPackagePath(dirname)
            )
@@ -87,6 +88,14 @@ def getPackageNameFromFullName(full_name):
     else:
         return None
 
+
+def getModuleFullNameFromPackageAndName(package, name):
+    if not package:
+        return name
+    else:
+        return package + '.' + name
+
+
 def getExtensionModuleSuffixes():
     for suffix, _mode, kind in imp.get_suffixes():
         if kind == imp.C_EXTENSION:
@@ -161,6 +170,7 @@ def warnAbout(importing, module_name, parent_package, level):
                     level_desc
                 )
 
+
 def normalizePackageName(module_name):
     # The "os.path" is strangely hacked into the "os" module, dispatching per
     # platform, we either cannot look into it, or we require that we resolve it
@@ -324,7 +334,7 @@ def _findModuleInPath2(module_name, search_path):
                     )
                     break
             else:
-                if Utils.python_version >= 330:
+                if python_version >= 330:
                     candidates.add(
                         (entry, 2, package_directory)
                     )
@@ -376,17 +386,21 @@ def getPackageSearchPath(package_name):
     if package_name is None:
         return [os.getcwd(), main_path] + sys.path
     elif '.' in package_name:
-        parent_package_name, package_name = package_name.rsplit('.', 1)
+        parent_package_name, child_package_name = package_name.rsplit('.', 1)
 
         result = []
         for element in getPackageSearchPath(parent_package_name):
             package_dir = Utils.joinpath(
                 element,
-                package_name
+                child_package_name
             )
 
             if isPackageDir(package_dir):
                 result.append(package_dir)
+                # Hack for "uniconverter". TODO: Move this to plug-in decision. This
+                # fails the above test, but at run time should be a package.
+            elif package_name == "uniconvertor.app.modules":
+                result.append(package_dir)
 
         return result
 
@@ -399,14 +413,13 @@ def getPackageSearchPath(package_name):
         def getPackageDirCandidates(element):
             yield Utils.joinpath(element, package_name), False
 
-            # Hack for PyWin32. TODO: Move this __path__ extensions to
+            # Hack for PyWin32. TODO: Move this "__path__" extensions to be
             # plug-in decisions.
             if package_name == "win32com":
                 yield Utils.joinpath(element, "win32comext"), True
 
         result = []
         for element in getPackageSearchPath(None):
-
             for package_dir, force_package in getPackageDirCandidates(element):
                 if isPackageDir(package_dir) or force_package:
                     result.append(package_dir)
