@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -184,6 +184,9 @@ areallylongpackageandmodulenametotestreprtruncation""",
         # test_runpy.py
         "test.script_helper",
 
+        # test_secrets.py
+        "secrets",
+
         # test_selectors.py
         "selectors",
 
@@ -226,6 +229,9 @@ areallylongpackageandmodulenametotestreprtruncation""",
         # test_unittest.py
         "unittest.test",
 
+        # test_wsgiref.py
+        "test.test_httpservers",
+
         # test_xml_etree.py
         "xml.parsers.expat.errors",
 
@@ -270,6 +276,9 @@ areallylongpackageandmodulenametotestreprtruncation""",
 
         # reportlab does use this if present only and warns about itself.
         "pyfribidi2", "macfs",
+
+        # psutils
+        "_psutil_windows",
     )
 
 
