@@ -109,14 +109,50 @@ class StatementAssignmentVariable(StatementChildrenHavingBase):
     def mayRaiseException(self, exception_type):
         return self.getAssignSource().mayRaiseException(exception_type)
 
-    def computeStatement(self, constraint_collection):
-        # This is very complex stuff, pylint: disable=R0912
+    def computeStatement(self, trace_collection):
+        # This is very complex stuff, pylint: disable=R0911,R0912
 
         # TODO: Way too ugly to have global trace kinds just here, and needs to
         # be abstracted somehow. But for now we let it live here: pylint: disable=R0915
 
+        source = self.getAssignSource()
+
+        if source.isExpressionSideEffects():
+            # If the assignment source has side effects, we can put them into a
+            # sequence and compute that instead.
+            statements = [
+                makeStatementExpressionOnlyReplacementNode(
+                    side_effect,
+                    self
+                )
+                for side_effect in
+                source.getSideEffects()
+            ]
+
+            statements.append(self)
+
+            # Remember out parent, we will assign it for the sequence to use.
+            parent = self.parent
+
+            # Need to update ourselves to no longer reference the side effects,
+            # but go to the wrapped thing.
+            self.setAssignSource(source.getExpression())
+
+            result = makeStatementsSequenceReplacementNode(
+                statements = statements,
+                node       = self,
+            )
+            result.parent = parent
+
+            return (
+                result.computeStatementsSequence(trace_collection),
+                "new_statements",
+"""\
+Side effects of assignments promoted to statements."""
+            )
+
         # Let assignment source may re-compute first.
-        constraint_collection.onExpression(self.getAssignSource())
+        trace_collection.onExpression(self.getAssignSource())
         source = self.getAssignSource()
 
         # No assignment will occur, if the assignment source raises, so give up
@@ -158,46 +194,16 @@ Assignment raises exception in assigned value, removed assignment."""
                 )
 
                 return result, "new_statements", """\
-Reduced assignment of variable '%s' from itself to mere access of it.""" % variable.getName()
+Reduced assignment of %s from itself to mere access of it.""" % variable.getDescription()
             else:
                 return None, "new_statements", """\
-Removed assignment of variable '%s' from itself which is known to be defined.""" % variable.getName()
+Removed assignment of %s from itself which is known to be defined.""" % variable.getDescription()
 
-        # If the assignment source has side effects, we can simply evaluate them
-        # beforehand, we have already visited and evaluated them before.
-        if source.isExpressionSideEffects():
-            statements = [
-                makeStatementExpressionOnlyReplacementNode(
-                    side_effect,
-                    self
-                )
-                for side_effect in
-                source.getSideEffects()
-            ]
 
-            statements.append(self)
-
-            parent = self.parent
-            result = makeStatementsSequenceReplacementNode(
-                statements = statements,
-                node       = self,
-            )
-            result.parent = parent
-
-            # Need to update it.
-            self.setAssignSource(source.getExpression())
-            source = self.getAssignSource()
-
-            constraint_collection.signalChange(
-                tags       = "new_statements",
-                message    = """\
-Side effects of assignments promoted to statements.""",
-                source_ref = self.getSourceReference()
-            )
 
         # Set-up the trace to the trace collection, so future references will
         # find this assignment.
-        self.variable_trace = constraint_collection.onVariableSet(
+        self.variable_trace = trace_collection.onVariableSet(
             assign_node = self
         )
 
@@ -376,11 +382,11 @@ class StatementDelVariable(StatementChildrenHavingBase):
         "variable_ref"
     )
 
-    def computeStatement(self, constraint_collection):
+    def computeStatement(self, trace_collection):
         variable_ref = self.getTargetVariableRef()
         variable = variable_ref.getVariable()
 
-        self.previous_trace = constraint_collection.getVariableCurrentTrace(variable)
+        self.previous_trace = trace_collection.getVariableCurrentTrace(variable)
 
         # First eliminate us entirely if we can.
         if self.tolerant and self.previous_trace.isUninitTrace():
@@ -398,21 +404,21 @@ class StatementDelVariable(StatementChildrenHavingBase):
 
         # If not tolerant, we may exception exit now during the __del__
         if not self.tolerant and not self.previous_trace.mustHaveValue():
-            constraint_collection.onExceptionRaiseExit(BaseException)
+            trace_collection.onExceptionRaiseExit(BaseException)
 
         # Record the deletion, needs to start a new version then.
-        constraint_collection.onVariableDel(
+        trace_collection.onVariableDel(
             variable_ref = variable_ref
         )
 
-        constraint_collection.onVariableContentEscapes(variable)
+        trace_collection.onVariableContentEscapes(variable)
 
         # Any code could be run, note that.
-        constraint_collection.onControlFlowEscape(self)
+        trace_collection.onControlFlowEscape(self)
 
         # Need to fetch the potentially invalidated variable. A "del" on a
         # or shared value, may easily assign the global variable in "__del__".
-        self.variable_trace = constraint_collection.getVariableCurrentTrace(variable)
+        self.variable_trace = trace_collection.getVariableCurrentTrace(variable)
 
         return self, None, None
 
@@ -495,8 +501,8 @@ class StatementReleaseVariable(NodeBase):
     def setVariable(self, variable):
         self.variable = variable
 
-    def computeStatement(self, constraint_collection):
-        self.variable_trace = constraint_collection.onVariableRelease(
+    def computeStatement(self, trace_collection):
+        self.variable_trace = trace_collection.onVariableRelease(
             variable = self.variable
         )
 
@@ -504,15 +510,15 @@ class StatementReleaseVariable(NodeBase):
             return (
                 None,
                 "new_statements",
-                "Uninitialized variable '%s' is not released." % (
-                    self.variable.getName()
+                "Uninitialized %s is not released." % (
+                    self.variable.getDescription()
                 )
             )
 
-        constraint_collection.onVariableContentEscapes(self.variable)
+        trace_collection.onVariableContentEscapes(self.variable)
 
         # Any code could be run, note that.
-        constraint_collection.onControlFlowEscape(self)
+        trace_collection.onControlFlowEscape(self)
 
         # TODO: We might be able to remove ourselves based on the trace
         # we belong to.
@@ -545,12 +551,16 @@ class ExpressionTargetVariableRef(ExpressionVariableRef):
             assert variable.getName() == variable_name
 
     def getDetailsForDisplay(self):
-        return {
+        result = {
             "variable_name" : self.variable_name,
             "version"       : self.variable_version,
-            "owner"         : self.variable.getOwner().getCodeName()
         }
 
+        if self.variable is not None:
+            result["owner"] = self.variable.getOwner().getCodeName()
+
+        return result
+
     @classmethod
     def fromXML(cls, provider, source_ref, **args):
         assert cls is ExpressionTargetVariableRef, cls
@@ -567,7 +577,7 @@ class ExpressionTargetVariableRef(ExpressionVariableRef):
             source_ref    = source_ref
         )
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         assert False, self.parent
 
     @staticmethod
@@ -610,15 +620,18 @@ class ExpressionTargetTempVariableRef(ExpressionTempVariableRef):
 
         owner = getOwnerFromCodeName(args["owner"])
         variable = owner.createTempVariable(args["temp_name"])
+        version = int(args["version"])
+
+        variable.version_number = max(variable.version_number, version)
 
         return cls(
             variable   = variable,
-            version    = int(args["version"]),
+            version    = version,
             source_ref = source_ref
         )
 
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         assert False, self.parent
 
     @staticmethod
