@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -25,21 +25,7 @@ answer quite a few questions at compile time.
 
 from nuitka.optimizations import BuiltinOptimization
 
-from .NodeBases import (
-    ExpressionBuiltinNoArgBase,
-    ExpressionBuiltinSingleArgBase
-)
-
-
-class ExpressionBuiltinOrd0(ExpressionBuiltinNoArgBase):
-    kind = "EXPRESSION_BUILTIN_ORD0"
-
-    def __init__(self, source_ref):
-        ExpressionBuiltinNoArgBase.__init__(
-            self,
-            builtin_function = ord,
-            source_ref       = source_ref
-        )
+from .NodeBases import ExpressionBuiltinSingleArgBase
 
 
 class ExpressionBuiltinOrd(ExpressionBuiltinSingleArgBase):
