@@ -23,7 +23,10 @@ source code comments with developer manual sections.
 """
 
 from nuitka.nodes.LoopNodes import StatementLoopBreak, StatementLoopContinue
-from nuitka.nodes.ReturnNodes import ExpressionReturnedValueRef, StatementReturn
+from nuitka.nodes.ReturnNodes import (
+    ExpressionReturnedValueRef,
+    StatementReturn
+)
 from nuitka.nodes.StatementNodes import (
     StatementPreserveFrameException,
     StatementPublishException,
@@ -79,7 +82,9 @@ def makeTryFinallyStatement(provider, tried, final, source_ref, public_exc = Fal
     assert tried is not None, source_ref
     assert final is not None, source_ref
 
-    if isDebug():
+    # TODO: Currently it's not possible anymore to get at XML for all codes
+    # during the building phase. So this error catcher cannot work currently.
+    if False and isDebug():
         final2 = final.makeClone()
         final2.parent = provider
 
