@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -15,7 +15,7 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-""" Reformulation of yield and yield from expressions.
+""" Reformulation of "yield" and "yield from" expressions.
 
 Consult the developer manual for information. TODO: Add ability to sync
 source code comments with developer manual sections.
@@ -24,10 +24,10 @@ source code comments with developer manual sections.
 
 import ast
 
-from nuitka.nodes.ConstantRefNodes import ExpressionConstantRef
+from nuitka.nodes.ConstantRefNodes import ExpressionConstantNoneRef
 from nuitka.nodes.YieldNodes import ExpressionYield, ExpressionYieldFrom
+from nuitka.PythonVersions import python_version
 from nuitka.tree import SyntaxErrors
-from nuitka.utils import Utils
 
 from .Helpers import buildNode
 
@@ -37,7 +37,7 @@ def _checkInsideGenerator(provider, node, source_ref):
         SyntaxErrors.raiseSyntaxError(
             "'yield' outside function",
             source_ref,
-            None if Utils.python_version < 300 else node.col_offset
+            None if python_version < 300 else node.col_offset
         )
 
     if provider.isExpressionCoroutineObjectBody():
@@ -62,8 +62,7 @@ def buildYieldNode(provider, node, source_ref):
         )
     else:
         return ExpressionYield(
-            expression = ExpressionConstantRef(
-                constant      = None,
+            expression = ExpressionConstantNoneRef(
                 source_ref    = source_ref,
                 user_provided = True
             ),
@@ -72,7 +71,7 @@ def buildYieldNode(provider, node, source_ref):
 
 
 def buildYieldFromNode(provider, node, source_ref):
-    assert Utils.python_version >= 330
+    assert python_version >= 330
 
     _checkInsideGenerator(provider, node, source_ref)
 
